package com.google.javascript.jscomp;

import com.google.common.flags.Flag;
import com.google.common.flags.FlagSpec;

import java.io.*;
import java.util.HashSet;
import java.util.List;
import java.util.logging.LogManager;


public class MyCompilerRunner extends CompilerRunner {

    @FlagSpec(help = "Specify stripTypes. You can include multiple.")
    public static final Flag<List<String>> FLAG_strip_types
            = Flag.stringCollector();

    @FlagSpec(help = "Specify stripTypePrefixes. You can include multiple.")
    public static final Flag<List<String>> FLAG_strip_type_prefixes = Flag.stringCollector();

    @FlagSpec(help = "Specify stripTypeSuffixes. You can include multiple.")
    public static final Flag<List<String>> FLAG_strip_name_suffixes
            = Flag.stringCollector();

    @FlagSpec(help = "Specify stripNamePrefixes. You can include multiple.")
    public static final Flag<List<String>> FLAG_strip_name_prefixes
            = Flag.stringCollector();

    @FlagSpec(help = "@export support.")
    public static final Flag<Boolean> FLAG_export_annotation
            = Flag.value(true);


      @FlagSpec(help = "Enables property renaming: HEURISTIC/AGGRESSIVE_HEURISTIC")
      public static final Flag<PropertyRenamingPolicy> FLAG_property_renaming_policy
          = Flag.value(PropertyRenamingPolicy.OFF);



    /*   */
    public MyCompilerRunner(String[] args) {
        super(args);
    }

    public MyCompilerRunner(String[] args, PrintStream out, PrintStream err) {
        super(args, out, err);
    }

    /*  ,      */
    @Override
    protected CompilerOptions createOptions() {

        CompilerOptions options = super.createOptions();

        options.stripTypes = new HashSet<String>(FLAG_strip_types.get());
        options.stripTypePrefixes = new HashSet<String>(FLAG_strip_type_prefixes.get());
        options.stripNameSuffixes = new HashSet<String>(FLAG_strip_name_suffixes.get());
        options.stripNamePrefixes = new HashSet<String>(FLAG_strip_name_prefixes.get());

        options.generateExports = FLAG_export_annotation.get();

        options.propertyRenaming = FLAG_property_renaming_policy.get();

        return options;
    }

    /*     */
    public static void main(String[] args) {

        /*
        try {
            File f = new File("c:\\logging.properties");
            InputStream in = new FileInputStream(f);
            BufferedInputStream bin = new BufferedInputStream(in);
            LogManager.getLogManager().readConfiguration(bin);
        } catch (Exception e) {
            throw new RuntimeException(e);
        }
        */
        (new MyCompilerRunner(args)).run();
    }

}
